import React, { useEffect, useState } from "react";
import { HeaderBlock, TipIcon } from "./header.style";
import { Popup, List } from "antd-mobile";
import { AlignLeftOutlined, BellOutlined } from "@ant-design/icons";
import { useCommonComponent } from "../../Utils/Utils";
import { useLocation, useHistory } from "react-router-dom";
import api from "../../Api/nodeApi";

function Header() {
  const isShow = useCommonComponent();
  const { pathname } = useLocation();
  const history = useHistory();
  const [showTip, setShowTip] = useState(false);
  const [visible, setVisible] = useState(false);
  const [typeList, setTypeList] = useState([]);

  useEffect(() => {
    //是否有新通知
    api.noticeApi().then((res) => {
      const { message, status } = res;
      const flag = message === "success" && status === 1;
      setShowTip(flag);
    });
  }, [isShow]);

  const curTitle = () => {
    const titleList = {
      "/home": "首页",
      "/shop": "购物",
      "/favorite": "收藏",
      "/user": "用户",
      "/search": "搜索",
    };
    return titleList[pathname];
  };

  //已读
  const readTip = () => {
    api.readApi().then((res) => {
      const { message } = res;
      const flag = message === "success";
      setShowTip(!flag);
    });
  };

  //获取所有分类信息
  const getListType = () => {
    api.getListApi().then((res) => {
      let typeList = res.map((k) => {
        return { classType: k.classType, classification: k.classification };
      });
      typeList = typeList.filter((currentValue, currentIndex, typeList) => {
        return (
          typeList.findIndex((x) => x.classType === currentValue.classType) ===
          currentIndex
        );
      });
      setTypeList(typeList);
      setVisible(true);
    });
  };

  //跳转对应分类页面
  const toTypePage = (type) => {
    setVisible(false);
    history.push("/search?type=" + type);
  };

  const leftContent = () => {
    return (
      <List header={<h4>类型</h4>}>
        {typeList.map((item) => (
          <List.Item
            key={item.classType}
            onClick={() => toTypePage(item.classType)}
          >
            {item.classification}
          </List.Item>
        ))}
      </List>
    );
  };

  return (
    <>
      {isShow ? (
        <HeaderBlock>
          <AlignLeftOutlined onClick={getListType} />
          <Popup
            visible={visible}
            onMaskClick={() => {
              setVisible(false);
            }}
            position="left"
            bodyStyle={{ width: "60vw" }}
          >
            {typeList.length > 0 ? leftContent() : null}
          </Popup>
          <div>{curTitle()}</div>
          <BellOutlined onClick={readTip} />
          {showTip ? <TipIcon /> : null}
        </HeaderBlock>
      ) : null}
    </>
  );
}

export default Header;
