import React, { useEffect, useState } from "react";
import { Form, Input } from "antd-mobile";
import {
  RegisterPage,
  RegForm,
  PasswordInput,
  SubmitBtn,
  ModalCard,
} from "./Register.style";
import RegisterBg from "../../assets/images/Register.png";
import { useHistory } from "react-router-dom";
import { EyeInvisibleOutline, EyeOutline } from "antd-mobile-icons";
import api from "../../Api/nodeApi";

// registered:注册---land:登陆
const Register = () => {
  const history = useHistory();
  const [visible, setVisible] = useState(false); //显示密码
  const [showModal, setShowModal] = useState(false); //显示模态框
  const [tip, setTip] = useState(""); //提示内容
  const [apiStatus, setApiStatus] = useState(false); //提示内容
  const pathType = history.location.search.split("?type=")[1];

  // 非手动关闭弹窗时,定时执行
  useEffect(() => {
    if (showModal) {
      setTimeout(() => {
        setShowModal(false);
        if (apiStatus) {
          sessionStorage.setItem("token", true);
          history.push("/home");
        } else {
          sessionStorage.setItem("token", null);
        }
      }, 1000);
    }
  }, [showModal]);

  const onFinish = (values) => {
    api
      .loginApi(values)
      .then((res) => {
        setTip(res);
        setShowModal(true);
        setApiStatus(true);
      })
      .catch((e) => {
        setTip(e.message);
        setShowModal(true);
        setApiStatus(false);
      });
  };

  const Declarative = () => {
    return (
      <ModalCard
        visible={showModal}
        content={tip}
        closeOnAction
        onClose={() => {
          setShowModal(false);
          if (apiStatus) {
            sessionStorage.setItem("token", true);
            history.push("/home");
          } else {
            sessionStorage.setItem("token", null);
          }
        }}
        actions={[
          {
            key: "confirm",
            text: "确认",
          },
        ]}
        style={{
          fontSize: "14px",
        }}
        bodyStyle={{
          fontSize: "14px",
        }}
      />
    );
  };

  return (
    <div
      style={{
        height: "100vh",
      }}
    >
      <div>
        <img src={RegisterBg} alt="" width="100%" />
      </div>
      <RegisterPage>
        <h2
          style={{
            textAlign: "center",
            color: "#419B92",
            fontSize: "16px",
          }}
        >
          {pathType === "land" ? "登陆" : "注册"}
        </h2>
        <Form
          name="basic"
          style={{
            "--border-top": "none",
            "--border-inner": "none",
          }}
          onFinish={onFinish}
          autoComplete="off"
        >
          <RegForm
            label="账号"
            name="account"
            rules={[
              {
                required: true,
                message: "请输入您的用户名!",
              },
            ]}
          >
            <Input placeholder="请输入用户名" />
          </RegForm>
          <RegForm
            label="密码"
            name="password"
            rules={[
              {
                required: true,
                message: "请输入您的密码!",
              },
            ]}
          >
            <PasswordInput>
              <Input
                placeholder="请输入密码"
                type={visible ? "text" : "password"}
              />
              <div className="eye">
                {!visible ? (
                  <EyeInvisibleOutline onClick={() => setVisible(true)} />
                ) : (
                  <EyeOutline onClick={() => setVisible(false)} />
                )}
              </div>
            </PasswordInput>
          </RegForm>
          <SubmitBtn type="submit">提交</SubmitBtn>
        </Form>
        {Declarative()}
      </RegisterPage>
    </div>
  );
};

export default Register;
