import React, { useEffect, useState } from "react";
import { PullToRefresh, InfiniteScroll, DotLoading } from "antd-mobile";
import { sleep } from "antd-mobile/es/utils/sleep";
import SearchInput from "../../Components/SearchInput/searchInput";
import { PageStyle } from "../pageCommon.style";
import { AllBox, PullDom, ItemCard } from "./Search.style";
import api from "../../Api/nodeApi";
import { useHistory } from "react-router-dom";

const Search = () => {
  const history = useHistory();
  const pathType = history.location.search.split("?type=")[1] || '';
  const [showData, setShowData] = useState([]); //展示数据
  const [pageNo, setPageNo] = useState(1);
  const [val, setVal] = useState("");
  const [hasMore, setHasMore] = useState(true);

  useEffect(()=>{
    InfiniteScrollContent()
  },[hasMore])

  useEffect(()=>{
    (async()=>{
      const res = await getList()
      setShowData(res)
    })()
  },[pathType])

  async function getList() {
    let allProductList = [];
    try {
      if (val || pathType) {
        allProductList =
          (await api.getSearchApi({ searchType: pathType, searchKey: val })) || [];
      } else {
        allProductList = (await api.getListApi({ pageNo })) || [];
      }
    } catch (e) {
      console.log("获取数据异常", e);
    }
    return allProductList;
  }
  //下拉刷新，上拉自动加载更多
  async function refreshAndLoadMore(type) {
    if (val && type === "up") {
      setHasMore(false);
      console.log("===", hasMore);
      return;
    }
    await sleep(2000);
    if (type === "down") {
      setShowData([]);
      setPageNo(1);
    } else {
      setPageNo(pageNo + 1);
    }
    const append = await getList();
    setShowData((val) => [...val, ...append]);
    setHasMore(append.length > 0);
  }
  const onEnterPress = (e) => {
    setVal(e.target.value)
    api.getSearchApi({ searchType: "", searchKey: e.target.value }).then((res) => {
      setShowData(res);
    });
  };
  const onClear = () => {
    api.getSearchApi({ searchType: "", searchKey: "" }).then((res) => {
      setShowData(res);
    });
  };
  const InfiniteScrollContent = () => {
    return (
      <>
        {hasMore ? (
          <>
            <span>正在加载</span>
            <DotLoading />
          </>
        ) : (
          <span>--- 没有更多了 ---</span>
        )}
      </>
    );
  };
  return (
    <PageStyle>
      <SearchInput
        placeholder="搜索关键字..."
        onEnterPress={onEnterPress}
        onClear={onClear}
      />
      <AllBox>
        <PullToRefresh onRefresh={() => refreshAndLoadMore("down")}>
          <PullDom>
            {showData.map((item, index) => (
              <ItemCard key={index}>{item.title}</ItemCard>
            ))}
          </PullDom>
        </PullToRefresh>
        <InfiniteScroll
          loadMore={() => refreshAndLoadMore("up")}
          hasMore={hasMore}
        >
          <InfiniteScrollContent hasMore={hasMore} />
        </InfiniteScroll>
      </AllBox>
    </PageStyle>
  );
};

export default Search;
